import random

chars = 'abcdefghijklmn0pqrstuvwxyz'
upper_chars = chars.upper()
special_chars ='#@'


def createPwd(char_length, include_special = False, include_upper = False):
    password = []
    for i in range(char_length):
        
        if include_special:
            password.append(random.choice(special_chars))
            include_special = False
        elif include_upper:
            password.append(random.choice(upper_chars))
            include_upper = False
        else:
            password.append(random.choice(chars))
            
    print(f"your password is: {''.join(password)}")

  

  


from setuptools import setup, find_packages

with open('README.md', 'r') as fh:
    long_description = fh.read()

setup(
    name = 'PwdGen2022',
    version = '0.0.0',
    author = 'Hugo Milesi',
    author_email = 'hugogmilesi@gmail.com',
    description = 'Simple password generator',
    license = 'MIT',
    packages = find_packages(),
    keywords = 'password',
    python_requires = '>= 3.6', 
    long_description_content_type="text/markdown",
    long_description=long_description,
)
